#!/bin/bash

#this script will build antora internal Pages
#see: https://docs.antora.org/antora/2.1/component-structure/

COURSE_NAME="example"
COURSE_VERSION="latest"
COURSE_FOLDER="example_17d_intro/17d_bolc/"
LESSON_PAGES_DIR="internal_pages"

#don't publish these to public, uses egrep so regex is ok

#i'm not really a programmer i just reference stack overflow: https://stackoverflow.com/questions/1951506/add-a-new-element-to-an-array-without-specifying-the-index-in-bash

if [ -e ${LESSON_PAGES_DIR} ] ; then
	rm -r ${LESSON_PAGES_DIR}
fi

### Set up ROOT module ###
mkdir -p ${LESSON_PAGES_DIR}/modules/ROOT/{pages,images,attachments}

if [ -e ./node_modules/reveal.js ]; then
	cp -r ./node_modules/reveal.js ${LESSON_PAGES_DIR}/modules/ROOT/attachments
	mkdir ${LESSON_PAGES_DIR}/modules/ROOT/attachments/slides
fi
#get cyber school logo
wget https://git.cybbh.space/global-objects/resources/raw/master/images/cyber-branch-insignia-official.png -O ${LESSON_PAGES_DIR}/modules/ROOT/images/cyber-branch-insignia-official.png

if [ -e ${COURSE_FOLDER}/course_intro.adoc ]; then
  cp "${COURSE_FOLDER}/course_intro.adoc" "${LESSON_PAGES_DIR}/modules/ROOT/pages/start.adoc"
  if [ -e "${COURSE_FOLDER}/json" ]; then
    cp -r "${COURSE_FOLDER}/json" "${LESSON_PAGES_DIR}/modules/ROOT/pages/"
  fi
else
  echo "" > "${LESSON_PAGES_DIR}/modules/ROOT/pages/start.adoc"
fi

printf "name: ${COURSE_NAME}\nversion: ${COURSE_VERSION}\nstart_page: ROOT:start.adoc\nnav:\n" > ${LESSON_PAGES_DIR}/antora.yml

### build individual lesson modules ###
find ${COURSE_FOLDER} -type f -name "lesson.json" | while read lesson; do
  lesson_folder="$(basename "$(dirname "${lesson}")")"
  module_folder="$(basename "$(dirname "$(dirname "${lesson}")../")")"

  if [ ! -e ${LESSON_PAGES_DIR}/modules/ROOT/nav-${module_folder}.adoc ]; then
    echo "* ${module_folder} " > ${LESSON_PAGES_DIR}/modules/ROOT/nav-${module_folder}.adoc
    printf " - modules/ROOT/nav-${module_folder}.adoc\n" >> ${LESSON_PAGES_DIR}/antora.yml
  fi
  mkdir -p ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages

  printf "** Lesson: ${lesson_folder}\n" >> ${LESSON_PAGES_DIR}/modules/ROOT/nav-${module_folder}.adoc

  printf "*** xref:${module_folder}.${lesson_folder}:guide.adoc[Facilitator Guide]\n" >> ${LESSON_PAGES_DIR}/modules/ROOT/nav-${module_folder}.adoc
		# build the FG sub-guides by LSA
  if [ ! -e ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc ] ; then
    touch ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
    find ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/*/ -name "guide.adoc" | sort | while read sub_fg; do
      echo $sub_fg
      sub_fg_path="$( echo "$sub_fg" | sed -e "s+${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/++")"
      sub_fg_name="$( echo "$sub_fg_path" | sed -e 's+/guide.adoc++')"
      printf "**** xref:${module_folder}.${lesson_folder}:lsa_fg/${sub_fg_path}[$sub_fg_name]\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
    done
  fi

  # set up practical exercises for this lesson
  printf "*** Practical Exercises\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
  find ${COURSE_FOLDER}${module_folder}/${lesson_folder}/practical_exercises/ -name "prompt.adoc" | sort | while read exercise; do
    exercise_name="$(basename "$(dirname "${exercise}")")"
    mkdir -p ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/practical_exercises
    cp -r ${COURSE_FOLDER}${module_folder}/${lesson_folder}/practical_exercises/${exercise_name} ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/practical_exercises
    printf "**** ${exercise_name}\n***** xref:${module_folder}.${lesson_folder}:practical_exercises/${exercise_name}/prompt.adoc[Prompt]\n***** xref:${module_folder}.${lesson_folder}:practical_exercises/${exercise_name}/solution.adoc[Solution]\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
  done


  #set up addtional files for this lesson
  printf "*** Additional Files\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
  cp -r ${COURSE_FOLDER}${module_folder}/${lesson_folder}/pages ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments
  if [ -e ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/public ] ; then
    printf "= Public Files List\n\n" > ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/public_attachments.adoc
    find ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/public -type f | while read f; do
      f_p="$(echo "$f" | sed -e "s+${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/++g")"
      printf "* link:{attachmentsdir}/${f_p}[${f_p}]\n" >> ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/public_attachments.adoc
    done
    printf "**** xref:${module_folder}.${lesson_folder}:public_attachments.adoc[Public]\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
  fi


  if [ -e ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/internal ] ; then
    printf "= Internal Files List\n\n" > ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/internal_attachments.adoc
    find ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/internal -type f | while read f; do
      f_p="$(echo "$f" | sed -e "s+${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/++g")"
      printf "* link:{attachmentsdir}/${f_p}[${f_p}]\n" >> ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/internal_attachments.adoc
    done
    printf "**** xref:${module_folder}.${lesson_folder}:internal_attachments.adoc[Internal]\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
  fi

  #set up student handouts for this lesson
  printf "*** Student Handouts\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
  if [ -e ${COURSE_FOLDER}${module_folder}/${lesson_folder}/student_handouts ] ; then
    cp -r ${COURSE_FOLDER}${module_folder}/${lesson_folder}/student_handouts ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/
    find ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/student_handouts -type f -name "*.adoc" | while read handout; do
      sed -i 's+include::../facilitator_guide/+include::facilitator_guide/+g' ${handout}
      handout_path="$(echo "$handout" | sed -e "s+${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/++g")"
      handout_name="$(echo "${handout_path}" | sed -e 's+student_handouts/++' | sed -e 's+\.adoc++')"
      printf "**** xref:${module_folder}.${lesson_folder}:${handout_path}[${handout_name}]\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
      cp -r ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/ ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/student_handouts/facilitator_guide
    done
  fi

  #set up slides for this lesson
  printf "*** xref:${module_folder}.${lesson_folder}:slides_rollup.adoc[Slides]\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
 # mkdir -p ${LESSON_PAGES_DIR}/modules/ROOT/attachments/slides/${module_folder}.${lesson_folder}/
  mkdir -p ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/slides
  touch ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/slides_rollup.adoc
  printf "Building slides\n"
  if [ -e ${COURSE_FOLDER}${module_folder}/${lesson_folder}/slides ]; then
    cp -r ${COURSE_FOLDER}${module_folder}/${lesson_folder}/slides/* ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/slides/.
    if [ -e ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/slides/nav.adoc ]; then
      cat ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/slides/nav.adoc >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
      rm ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/slides/nav.adoc
    fi
#printf "* link:{attachmentsdir}/${f_p}[${f_p}]\n" >> ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/public_attachments.adoc
    curdir="$(pwd)"
#    cd ${LESSON_PAGES_DIR}/modules/ROOT/attachments/slides/${module_folder}.${lesson_folder}/
    cd ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/attachments/slides
    find -name "*.adoc" | while read slidedeck; do
      node "${curdir}/asciidoctor-revealjs.js" "$slidedeck"
      rm "$slidedeck"
      newfile="$(echo $slidedeck | sed 's+./++' |sed 's/.adoc//g')"
      sed -i 's+node_modules/reveal.js/+../../../_attachments/reveal.js/+g' ${newfile}.html
      printf "* link:{attachmentsdir}/slides/${newfile}.html[${newfile}]\n" >> ${curdir}/${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/slides_rollup.adoc
    done
    cd $curdir
  fi
  printf "Done slides\n"

  # set up lesson plan page for this antora module
  if [ -e ${lesson}.adoc ] ; then
    mv ${lesson}.adoc ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/lesson_plan.adoc
    #prevent embedded FG includes from executing
    sed -i 's/include::/-include::/g' ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/lesson_plan.adoc
    #but do include tradoc variables
    sed -i 's+-include::tradoc+include::tradoc+g' ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/lesson_plan.adoc
    #sed -i 's+-include::https:+include::https:+g' ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/lesson_plan.adoc

    #remove the partial page markers
    sed -i 's/:page-partial://g' ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/lesson_plan.adoc

    #move supporting tradoc variables
    cp tradoc*.adoc ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/
    printf "*** xref:${module_folder}.${lesson_folder}:lesson_plan.adoc[TD Lesson Plan]\n" >> ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
  fi

  cat  ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc
  cat  ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc >> ${LESSON_PAGES_DIR}/modules/ROOT/nav-${module_folder}.adoc
  rm ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/nav.adoc

  #copy the FG for the sub-lsas
		cp -r ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/lsa_fg/
		rm ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/lsa_fg/guide.adoc

	 # copy the FG for the main FG
  cp -r ${COURSE_FOLDER}${module_folder}/${lesson_folder}/facilitator_guide/* ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages/
#  printf "* Lesson: \n** xref:guide.adoc[Facilitator Guide]\n" > ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/nav.adoc
#  printf " - modules/${module_folder}.${lesson_folder}/nav.adoc\n" >> ${LESSON_PAGES_DIR}/antora.yml

  # fix images
		if [ -e ${COURSE_FOLDER}${module_folder}/${lesson_folder}/images ]; then
    cp -r ${COURSE_FOLDER}${module_folder}/${lesson_folder}/images ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}
		else
    mkdir ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/images
		fi
	 find ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages -type f \( -iname \*.jpg -o -iname \*.png -o -iname \*.gif -o -iname \*.svg \) | while read img; do
			  mv ${img} ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/images
		done
		find ${LESSON_PAGES_DIR}/modules/${module_folder}.${lesson_folder}/pages -name "*.adoc" | while read adoc; do
		  sed -i 's+^image::.*/+image::+gi' "${adoc}"
		done

  FILENAME="${module_folder}.${lesson_folder}.adoc"
  LESSONS+=("${FILENAME}")
done

(
 cd ${LESSON_PAGES_DIR}
 git init
 git add .
 git commit -m "first commit!"
)
