# Lesson Folder Documentation

The Lesson folder ("lesson1") is treated as a single unit. Everything should be designed so that moving the folder itself won't break anything but components inside the directory can hard-code relative references to each other.

This is to facilitate the "Don't Repeat Yourself" principle (https://en.wikipedia.org/wiki/Don%27t_repeat_yourself). As muh as possible, all curriculum should be stored once within the project to facilitate efficient and effective curriculum management. For example, if a part of a facilitator guide is releasable as a student handout, tag the section and then refer to it in the student handout via a relative path inclusion.


# JSON files:

lesson.json is the master definition for this lesson. This should capture everything about the lesson; the lesson.json can refer to other flat files or other json files. This defines what is output into the lesson plan for training development.

# Gitlab Pages

The Gitlab pages for the course will be driven by antora. This means that the CI/CD pipeline will reformat the material to be consistent with antora's requirements.

An Antora lesson plan directory will be broken down into several sections.

The Internal Instructor Layout, per lesson folder:

* Facilitator Guide - generated from the top-level facilitator guide.
* Activities - every activity gets two sub entries
 * Activity1 Prompt
 * Activity1 Solution
 * Activity2 Prompt
 * Activity2 Solution
* Student Handouts - every adoc in student_handouts is placed in here
* Redacted Master Lesson Plan - without test data; the test data is only pushed to the TD view.
* Additional Files - anything in the pages/internal directory gets placed here.

The Public Student Layout, per lesson folder:
* Facilitation Guide - the non-private portions of the facilitation guide
* Student Handouts - every adoc in student_handouts is placed in here
* Activities - every activity gets two sub entries
 * Activity1 Prompt
 * Activity2 Prompt
* Additional Files - anything in the pages/public directory gets placed here.



# Folder Breakdown


## viewgraph_masters

These include asciidoctor slide decks, graphics, links to video clips, or other resources that support the lesson instruction.

## student_handouts

This contains all of the data that is releasable to students. The CICD pipeline will eventually move this to student handouts folder

## practical_exercises

This contains all of the supporting files for practical exercises in the class. Each exercise should get its own subfolder and all the material supporting the exercise should be stored in here. This includes both the exercise prompt and solution.

## pages

This folder contains two sub-directories. The public sub-directory contains any files that will be pushed to the public gitlab pages static files folder for this lesson.

Any instance of the "pages" folder within a lesson folder, whether directly beneath the lesson folder or in any subdirectories, will all be flattened together. Anything in the flattened public folder will be released to the student pages page. Anything in the flattened internal folder will be placed in the internal pages page.


```
pages
 \
  - public
  |  
  |      
  - internal
```

## tests

This contains the actual test data for the lesson, if applicable.

## facilitator_guide

the facilitator guide goes in here. How it is broken up is dependent on the lesson, but the final lesson guide should be titled `guide.adoc`


## examples

Examples can either be placed in the examples folder, or if they can be published to pages, inside the pages folder. If an example is not placed in a pages folder, it will only be accessible in the repository itself.
